==> beep_edition-7.x-1.1.tar.gz: beep_edition/js/beep_edition-script.js <==
/**
 * @file
 * Global JavaScript file for the site.
 */


// base function for using flexslider
(function ($) {
  // All your code here
	$(window).load(function() {
		$('.flexslider').flexslider({
			animation: "slide",
			slideshowSpeed: 7000,
			controlsContainer: ".flexslider-container"
		});
		// Only add the toggle class if there are child pages
		$('.main-menu > div > .nice-menu > li > a + ul').after('<span class="js-toggle-dropdown"><span class="icon icon-plus-sign"></span></span>');
		$('.js-toggle-dropdown').click(function(e) {
			e.preventDefault();
			$(this).parent().toggleClass('nav-dropdown-expanded');
			$(this).find('span').toggleClass('icon-plus-sign icon-remove-sign');
		});

	});
	Drupal.behaviors.something = {
		attach: function (context, settings) {
			$('#nav-toggle').click(function(e) {
				e.preventDefault();
				$('.main-menu').toggleClass('open');
				$('body').toggleClass('nav-open');
				$(this).find('span').toggleClass('icon-reorder icon-remove-sign');

			});
			$(window).resize(function() {
				// this is here to demonstrate tapping into media queries in JS using Modernizr
				$('body').removeClass('mq-phone');
				$('body').removeClass('mq-phone_wide-sm_tab');
				$('body').removeClass('mq-lg_tab');
				$('body').removeClass('mq-desktop');
				if(Modernizr.mq('only all and (min-width: 900px)')) {
					$('body').addClass('mq-desktop');
				} else if(Modernizr.mq('only all and (min-width: 700px)')) {
					$('body').addClass('mq-lg_tab');
				} else if(Modernizr.mq('only all and (min-width: 400px)')) {
					$('body').addClass('mq-phone_wide-sm_tab');
				} else {
					$('body').addClass('mq-phone');
				}
			});
		}
	};
})(jQuery);

// Rewritten version for correcting a screen-zoom issue on rotation in iOS
// By @mathias, @cheeaun and @jdalton

(function(doc) {

	var addEvent = 'addEventListener',
		type = 'gesturestart',
		qsa = 'querySelectorAll',
		scales = [1, 1],
		meta = qsa in doc ? doc[qsa]('meta[name=viewport]') : [];

	function fix() {
		meta.content = 'width=device-width,minimum-scale=' + scales[0] + ',maximum-scale=' + scales[1];
		doc.removeEventListener(type, fix, true);
	}

	if ((meta = meta[meta.length - 1]) && addEvent in doc) {
		fix();
		scales = [0.25, 1.6];
		doc[addEvent](type, fix, true);
	}

}(document));

==> beep_edition-7.x-2.0.tar.gz: beep_edition/js/beep_edition-script.js <==
/**
 * @file
 * Global JavaScript file for the site.
 */


// base function for using flexslider
(function ($) {
  // All your code here
	$(window).load(function() {
		$('.flexslider').flexslider({
			animation: "slide",
			slideshowSpeed: 7000,
			controlsContainer: ".flexslider-container"
		});
		// Only add the toggle class if there are child pages
		$('.main-menu > div > .nice-menu > li > a + ul').after('<span class="js-toggle-dropdown"><span class="icon icon-plus-sign"></span></span>');
		$('.js-toggle-dropdown').click(function(e) {
			e.preventDefault();
			$(this).parent().toggleClass('nav-dropdown-expanded');
			$(this).find('span').toggleClass('fa-plus-circle fa-times-circle');
		});

	});
	Drupal.behaviors.something = {
		attach: function (context, settings) {
			$('#nav-toggle').click(function(e) {
				e.preventDefault();
				$('.main-menu').toggleClass('open');
				$('body').toggleClass('nav-open');
				$(this).find('span').toggleClass('fa-bars fa-times-circle');

			});
			$(window).resize(function() {
				// this is here to demonstrate tapping into media queries in JS using Modernizr
				$('body').removeClass('mq-phone');
				$('body').removeClass('mq-sm_tab');
				$('body').removeClass('mq-lg_tab');
				$('body').removeClass('mq-desk');
				$('body').removeClass('mq-desk-plus');
				if(Modernizr.mq('only all and (min-width: 80em)')) {
					$('body').addClass('mq-desk-plus');
				} else if(Modernizr.mq('only all and (min-width: 58em)')) {
					$('body').addClass('mq-desk');
				} else if(Modernizr.mq('only all and (min-width: 45em)')) {
					$('body').addClass('mq-lg_tab');
				} else if(Modernizr.mq('only all and (min-width: 25em)')) {
					$('body').addClass('mq-sm_tab');
				} else {
					$('body').addClass('mq-phone');
				}
			});
		}
	};
})(jQuery);

// Rewritten version for correcting a screen-zoom issue on rotation in iOS
// By @mathias, @cheeaun and @jdalton

(function(doc) {

	var addEvent = 'addEventListener',
		type = 'gesturestart',
		qsa = 'querySelectorAll',
		scales = [1, 1],
		meta = qsa in doc ? doc[qsa]('meta[name=viewport]') : [];

	function fix() {
		meta.content = 'width=device-width,minimum-scale=' + scales[0] + ',maximum-scale=' + scales[1];
		doc.removeEventListener(type, fix, true);
	}

	if ((meta = meta[meta.length - 1]) && addEvent in doc) {
		fix();
		scales = [0.25, 1.6];
		doc[addEvent](type, fix, true);
	}

}(document));
